MoscoreAnomaly
=======================================================

.. currentmodule:: skchange.anomaly_detectors

.. autoclass:: MoscoreAnomaly

.. include:: skchange.anomaly_detectors.MoscoreAnomaly.examples

.. raw:: html

    <div class="clearer"></div>